@@ -24,20 +24,12 @@
 // define if tailrings should be used
 #define HAVE_TAIL_RING
 
-#if 1
-#define setmax 16
+#define setmax 128
 #define setmaxL ((4096-12)/sizeof(LObject))
 #define setmaxLinc ((4096)/sizeof(LObject))
 
-#define setmaxT 64
-#define setmaxTinc 32
-#else
-#define setmax 16
-#define setmaxL 16
-#define setmaxLinc 16
-#define setmaxT 16
-#define setmaxTinc 16
-#endif
+#define setmaxT ((4096-12)/sizeof(TObject))
+#define setmaxTinc ((4096)/sizeof(TObject))
 
 // if you want std computations as in Singular version < 2:
 // This disables RedThrough, tailReductions against T (bba),
@@ -425,8 +417,7 @@ void initEcartPairBba (LObject* Lp,poly f,poly g,int ecartF,int ecartG);
 void initEcartPairMora (LObject* Lp,poly f,poly g,int ecartF,int ecartG);
 int posInS (const kStrategy strat, const int length, const poly p,
             const int ecart_p);
-int posInSMonFirst (const kStrategy strat, const int length, const poly p,
-            const int ecart_p);
+int posInSMonFirst (const kStrategy strat, const int length, const poly p);
 int posInIdealMonFirst (const ideal F, const poly p,int start = 0,int end = -1);
 int posInT0 (const TSet set,const int length,LObject &p);
 int posInT1 (const TSet set,const int length,LObject &p);
@@ -527,9 +518,7 @@ void enterpairsSig (poly h, poly hSig, int from, int k, int ec, int pos,kStrateg
 void enterpairs (poly h, int k, int ec, int pos,kStrategy strat, int atR = -1);
 void entersets (LObject h);
 void pairs ();
-BOOLEAN enterOneStrongPoly (int i,poly p,int /*ecart*/, int /*isFromQ*/,kStrategy strat, int atR = -1, bool enterTstrong = FALSE);
 BOOLEAN sbaCheckGcdPair (LObject* h,kStrategy strat);
-BOOLEAN enterOneStrongPolySig (int i,poly p,poly sig,int /*ecart*/, int /*isFromQ*/,kStrategy strat, int atR = -1);
 void message (int i,int* reduc,int* olddeg,kStrategy strat,int red_result);
 void messageStat (int hilbcount,kStrategy strat);
 void messageStatSBA (int hilbcount,kStrategy strat);
@@ -576,9 +565,6 @@ void updateResult(ideal r,ideal Q,kStrategy strat);
 void completeReduce (kStrategy strat, BOOLEAN withT=FALSE);
 void kFreeStrat(kStrategy strat);
 void enterOnePairNormal (int i,poly p,int ecart, int isFromQ,kStrategy strat, int atR);
-void enterOnePairLift (int i,poly p,int ecart, int isFromQ,kStrategy strat, int atR);
-void enterOnePairSig (int i,poly p,poly pSig,int ecart, int isFromQ,kStrategy strat, int atR);
-void enterOnePairSigRing (int i,poly p,poly pSig,int ecart, int isFromQ,kStrategy strat, int atR);
 void chainCritNormal (poly p,int ecart,kStrategy strat);
 void chainCritOpt_1 (poly,int,kStrategy strat);
 void chainCritSig (poly p,int ecart,kStrategy strat);
@@ -830,16 +816,12 @@ void enterTShift(LObject p, kStrategy strat, int atT, int uptodeg, int lV);
 
 void initBuchMoraShift (ideal F,ideal Q,kStrategy strat);
 
-void enterOnePairManyShifts (int i, poly p, int ecart, int isFromQ, kStrategy strat, int atR, int uptodeg, int lV); // ok
-
 void enterOnePairSelfShifts (poly qq, poly p, int ecart, int isFromQ, kStrategy strat, int atR, int uptodeg, int lV);
 
 void enterOnePairShift (poly q, poly p, int ecart, int isFromQ, kStrategy strat, int atR, int ecartq, int qisFromQ, int shiftcount, int ifromS, int uptodeg, int lV); // ok
 
 void enterpairsShift (poly h,int k,int ecart,int pos,kStrategy strat, int atR,int uptodeg, int lV);
 
-void initenterpairsShift (poly h,int k,int ecart,int isFromQ,kStrategy strat, int atR,int uptodeg, int lV);
-
 void updateSShift(kStrategy strat,int uptodeg,int lV);
 
 void initBbaShift(kStrategy strat);
